ReactiveObserver class

Constructors

ReactiveObserver({required void onTransaction<ResultType>(ReactiveTransaction<ResultType> transaction, ResultType? result, String? reactiveName), String? name})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
final
onTransaction → void Function<ResultType>(ReactiveTransaction<ResultType> transaction, ResultType? result, String? reactiveName)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveTransaction<ResultType>(ReactiveTransaction<ResultType> transaction, ResultType? result, Reactive reactive) → void
register(Reactive reactive) → void
toString() String
A string representation of this object.
inherited
unregister(Reactive reactive) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited